==> eiffelstudio-16.05.tar: F_code/C15/xm701.c <==
/*
 * Code for class XM_XPATH_TRACING_NODE_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm701.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_TRACING_NODE_ITERATOR}.make */
void F1564_13351 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XPATH_TRACING_NODE_ITERATOR}.item */
EIF_REFERENCE F1564_13352 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	RTCT0("precondition_not_off", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	Result = (EIF_REFERENCE) loc1;
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_NODE_ITERATOR}.after */
EIF_BOOLEAN F1564_13353 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10508[Dtype(tr1)-1559])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_NODE_ITERATOR}.forth */
void F1564_13355 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_) == ((EIF_INTEGER_32) 0L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10521[Dtype(tr1)-1558])(RTCW(tr1));
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10522[Dtype(tr1)-1559])(RTCW(tr1));
	}
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_))++;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O10503[Dtype(tr1)-1558]);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		F1559_13287(Current, loc2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10508[Dtype(tr1)-1559])(RTCW(tr1));
		if ((EIF_BOOLEAN) !tb1) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10501[Dtype(tr1)-1559])(RTCW(tr1));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
			tr1 = RTOSCF(7996,F1079_7996,(Current));
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr3 = RTMS_EX_H(" [",2,8283);
			loc1 = F1064_7836(RTCW(tr1), tr2, tr3);
			tr1 = RTOSCF(7996,F1079_7996,(Current));
			ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_);
			tr2 = c_outi(ti4_1);
			loc1 = F1064_7843(RTCW(tr1), loc1, tr2);
			tr1 = RTOSCF(7996,F1079_7996,(Current));
			tr2 = RTMS_EX_H("]",1,93);
			loc1 = F1064_7843(RTCW(tr1), loc1, tr2);
			tr1 = F1564_13352(Current);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F1130_9178(Current, loc1, tr1, tr2);
		} else {
			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_)) {
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
				tr2 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
				F1130_9178(Current, tr1, NULL, tr2);
			}
		}
	}
	RTLE;
}

/* {XM_XPATH_TRACING_NODE_ITERATOR}.another */
EIF_REFERENCE F1564_13356 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLR(5,Result);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNSMART(Dftype(Current));
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10528[Dtype(tr2)-1559])(RTCW(tr2));
	tr3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	tr4 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	F1564_13351(RTCW(tr1), tr2, tr3, tr4);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_NODE_ITERATOR}.base_iterator */
EIF_REFERENCE F1564_13357 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_XPATH_TRACING_NODE_ITERATOR}.label */
EIF_REFERENCE F1564_13358 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {XM_XPATH_TRACING_NODE_ITERATOR}.context */
EIF_REFERENCE F1564_13359 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {XM_XPATH_TRACING_NODE_ITERATOR}.internal_item */
EIF_REFERENCE F1564_13360 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


void EIF_Minit701 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.01.10.1424.tar: F_code/C15/xm701.c <==
/*
 * Code for class XM_XPATH_TRACING_ITERATOR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm701.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_TRACING_ITERATOR}.make */
void F1564_13380 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg3;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTLE;
}

/* {XM_XPATH_TRACING_ITERATOR}.item */
EIF_REFERENCE F1564_13381 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	RTCT0("precondition_not_off", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	Result = (EIF_REFERENCE) loc1;
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.after */
EIF_BOOLEAN F1564_13382 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10491[Dtype(tr1)-1559])(RTCW(tr1));
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.forth */
void F1564_13384 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,tr2);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_) == ((EIF_INTEGER_32) 0L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10504[Dtype(tr1)-1558])(RTCW(tr1));
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R10505[Dtype(tr1)-1559])(RTCW(tr1));
	}
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_))++;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O10486[Dtype(tr1)-1558]);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		F1559_13316(Current, loc2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R10491[Dtype(tr1)-1559])(RTCW(tr1));
		if ((EIF_BOOLEAN) !tb1) {
			*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10484[Dtype(tr1)-1559])(RTCW(tr1));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
			tr1 = RTOSCF(8220,F1128_8220,(Current));
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
			tr3 = RTMS_EX_H(" [",2,8283);
			loc1 = F1113_8057(RTCW(tr1), tr2, tr3);
			tr1 = RTOSCF(8220,F1128_8220,(Current));
			ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_6_2_0_0_);
			tr2 = c_outi(ti4_1);
			loc1 = F1113_8067(RTCW(tr1), loc1, tr2);
			tr1 = RTOSCF(8220,F1128_8220,(Current));
			tr2 = RTMS_EX_H("]",1,93);
			loc1 = F1113_8067(RTCW(tr1), loc1, tr2);
			tr1 = F1564_13381(Current);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			F1180_9420(Current, loc1, tr1, tr2);
		} else {
			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_6_1_)) {
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
				tr2 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
				F1180_9420(Current, tr1, NULL, tr2);
			}
		}
	}
	RTLE;
}

/* {XM_XPATH_TRACING_ITERATOR}.another */
EIF_REFERENCE F1564_13385 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLR(5,Result);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNSMART(Dftype(Current));
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R10511[Dtype(tr2)-1559])(RTCW(tr2));
	tr3 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	tr4 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	F1564_13380(RTCW(tr1), tr2, tr3, tr4);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {XM_XPATH_TRACING_ITERATOR}.base_iterator */
EIF_REFERENCE F1564_13386 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_XPATH_TRACING_ITERATOR}.label */
EIF_REFERENCE F1564_13387 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {XM_XPATH_TRACING_ITERATOR}.context */
EIF_REFERENCE F1564_13388 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {XM_XPATH_TRACING_ITERATOR}.internal_item */
EIF_REFERENCE F1564_13389 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


void EIF_Minit701 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
